import { RouterView } from 'vue-router';

const ticketCard = {
    name: 'TicketCard',
    path: ':id',
    component: () => import('src/pages/Ticket/Card/TicketCard.vue'),
    redirect: { name: 'TicketSummary' },
    meta: {
        menu: [
            'TicketBasicData',
            'TicketSale',
            'TicketLog',
            'TicketExpedition',
            'TicketDms',
            'TicketPurchaseRequest',
            'TicketTracking',
            'TicketNotes',
            'TicketPicture',
            'TicketVolume',
            'TicketComponents',
            'TicketPackage',
            'TicketService',
            'TicketSaleTracking',
            'TicketBoxing',
            'TicketSms',
        ],
    },
    children: [
        {
            path: 'summary',
            name: 'TicketSummary',
            meta: {
                title: 'summary',
                icon: 'launch',
            },
            component: () => import('src/pages/Ticket/Card/TicketSummary.vue'),
        },
        {
            path: 'basic-data',
            name: 'TicketBasicData',
            meta: {
                title: 'basicData',
                icon: 'vn:settings',
            },
            component: () =>
                import('src/pages/Ticket/Card/BasicData/TicketBasicDataView.vue'),
        },
        {
            path: 'sale',
            name: 'TicketSale',
            meta: {
                title: 'sale',
                icon: 'vn:lines',
            },
            component: () => import('src/pages/Ticket/Card/TicketSale.vue'),
        },
        {
            path: 'request',
            name: 'TicketPurchaseRequest',
            meta: {
                title: 'purchaseRequest',
                icon: 'vn:buyrequest',
            },
            component: () => import('src/pages/Ticket/Card/TicketPurchaseRequest.vue'),
        },
        {
            path: 'tracking',
            name: 'TicketTracking',
            meta: {
                title: 'tracking',
                icon: 'vn:eye',
            },
            component: () => import('src/pages/Ticket/Card/TicketTracking.vue'),
        },
        {
            path: 'log',
            name: 'TicketLog',
            meta: {
                title: 'log',
                icon: 'history',
            },
            component: () => import('src/pages/Ticket/Card/TicketLog.vue'),
        },
        {
            path: 'observation',
            name: 'TicketNotes',
            meta: {
                title: 'notes',
                icon: 'vn:notes',
            },
            component: () => import('src/pages/Ticket/Card/TicketNotes.vue'),
        },
        {
            path: 'picture',
            name: 'TicketPicture',
            meta: {
                title: 'pictures',
                icon: 'vn:photo',
            },
            component: () => import('src/pages/Ticket/Card/TicketPicture.vue'),
        },
        {
            path: 'volume',
            name: 'TicketVolume',
            meta: {
                title: 'volume',
                icon: 'vn:volume',
            },
            component: () => import('src/pages/Ticket/Card/TicketVolume.vue'),
        },
        {
            path: 'expedition',
            name: 'TicketExpedition',
            meta: {
                title: 'expedition',
                icon: 'vn:package',
            },
            component: () => import('src/pages/Ticket/Card/TicketExpedition.vue'),
        },
        {
            path: 'service',
            name: 'TicketService',
            meta: {
                title: 'services',
                icon: 'vn:services',
            },
            component: () => import('src/pages/Ticket/Card/TicketService.vue'),
        },
        {
            path: 'package',
            name: 'TicketPackage',
            meta: {
                title: 'packages',
                icon: 'vn:bucket',
            },
            component: () => import('src/pages/Ticket/Card/TicketPackage.vue'),
        },
        {
            path: 'components',
            name: 'TicketComponents',
            meta: {
                title: 'components',
                icon: 'vn:components',
            },
            component: () => import('src/pages/Ticket/Card/TicketComponents.vue'),
        },

        {
            path: 'sale-tracking',
            name: 'TicketSaleTracking',
            meta: {
                title: 'saleTracking',
                icon: 'assignment',
            },
            component: () => import('src/pages/Ticket/Card/TicketSaleTracking.vue'),
        },
        {
            path: 'dms',
            name: 'TicketDms',
            meta: {
                title: 'dms',
                icon: 'cloud_upload',
            },
            component: () => import('src/pages/Ticket/Card/TicketDms.vue'),
        },
        {
            path: 'boxing',
            name: 'TicketBoxing',
            meta: {
                title: 'boxing',
                icon: 'science',
            },
            component: () => import('src/pages/Ticket/Card/TicketBoxing.vue'),
        },
        {
            path: 'sms',
            name: 'TicketSms',
            meta: {
                title: 'sms',
                icon: 'sms',
            },
            component: () => import('src/pages/Ticket/Card/TicketSms.vue'),
        },
    ],
};

export default {
    name: 'Ticket',
    path: '/ticket',
    meta: {
        title: 'tickets',
        icon: 'vn:ticket',
        moduleName: 'Ticket',
        keyBinding: 't',
        menu: ['TicketList', 'TicketAdvance', 'TicketWeekly', 'TicketFuture'],
    },
    component: RouterView,
    redirect: { name: 'TicketMain' },
    children: [
        {
            name: 'TicketMain',
            path: '',
            component: () => import('src/components/common/VnModule.vue'),
            redirect: { name: 'TicketIndexMain' },
            children: [
                {
                    path: '',
                    name: 'TicketIndexMain',
                    redirect: { name: 'TicketList' },
                    component: () => import('src/pages/Ticket/TicketList.vue'),
                    children: [
                        {
                            name: 'TicketList',
                            path: 'list',
                            meta: {
                                title: 'list',
                                icon: 'view_list',
                            },
                        },
                        ticketCard,
                    ],
                },
                {
                    path: 'create',
                    name: 'TicketCreate',
                    meta: {
                        title: 'createTicket',
                        icon: 'vn:ticketAdd',
                    },
                    component: () => import('src/pages/Ticket/TicketCreate.vue'),
                },
                {
                    path: 'weekly',
                    name: 'TicketWeekly',
                    meta: {
                        title: 'weeklyTickets',
                        icon: 'access_time',
                    },
                    component: () => import('src/pages/Ticket/TicketWeekly.vue'),
                },
                {
                    path: 'future',
                    name: 'TicketFuture',
                    meta: {
                        title: 'futureTickets',
                        icon: 'keyboard_double_arrow_right',
                    },
                    component: () => import('src/pages/Ticket/TicketFuture.vue'),
                },
                {
                    name: 'TicketAdvance',
                    path: 'advance',
                    meta: {
                        title: 'ticketAdvance',
                        icon: 'keyboard_double_arrow_left',
                    },
                    component: () => import('src/pages/Ticket/TicketAdvance.vue'),
                },
            ],
        },
    ],
};
